#
# spec file for package mypaint
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           mypaint
Version:        2.0.0
Release:        lp152.2.1
Summary:        Graphics application for digital painters
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Other
URL:            http://mypaint.org
Source:         https://github.com/mypaint/mypaint/releases/download/v%{version}/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM mypaint-python3-pass-str-to-exec.patch badshah400@gmail.com -- Fix build with python3 by passing a str object as the first arg to exec instead of an open file object
Patch0:         mypaint-python3-pass-str-to-exec.patch
BuildRequires:  ImageMagick
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  librsvg
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  python3-cairo-devel
BuildRequires:  python3-devel
BuildRequires:  python3-gobject-devel
BuildRequires:  python3-numpy >= 1.5
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-setuptools
BuildRequires:  swig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libmypaint) >= 1.5.0
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(mypaint-brushes-2.0) >= 2.0.2
BuildRequires:  pkgconfig(pygobject-3.0)
Requires:       mypaint-brushes >= 2.0.2
Requires:       python3-gobject-Gdk
Requires:       python3-numpy >= 1.7
Requires:       python3-pycairo
Recommends:     %{name}-lang = %{version}
%lang_package

%description
MyPaint is a graphics application for digital painters. It supports
graphics tablets made by Wacom, and many similar devices. The
standard brushes can emulate traditional media like charcoal,
pencils, ink, or paint.

%prep
%autosetup -p1

%build
%python_build 

%install
%python_install

%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_libexecdir}/%{name}/

%check
python3 setup.py test

%files
%doc Changelog.md README.md
%license COPYING Licenses.md
%{_bindir}/%{name}
%{_datadir}/mypaint/
%{_datadir}/icons/hicolor/*/*/*.*
%{_libexecdir}/mypaint/
%{_datadir}/thumbnailers/
%{_bindir}/mypaint-ora-thumbnailer
%{_datadir}/metainfo/mypaint.appdata.xml
%{_datadir}/applications/mypaint.desktop

%files lang -f %{name}.lang

%changelog
* Wed May 27 2020 Atri Bhattacharya <badshah400@gmail.com>
- Fix run time dependencies:
  * Requires -- rather than Recommends -- mypaint-brushes, doesn't
    launch when the app is unable to find brushes.
  * Requires python3-pycairo.
* Tue Feb 18 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.0:
  * New features:
  - Linear compositing and spectral blending (pigment).
  - Layer views.
  - Brush strokes dependent on view rotation and view zoom.
  - Additional symmetry modes: vertical, vertical+horizontal,
    rotational, snowflake.
  - Expanded flood fill functionality: offset, feather, gap
    detection and more.
  - New brush settings: offsets, gridmap, additional smudge
    settings, posterize, pigment.
  - New brush inputs: barrel rotation, base radius, zoom level,
    gridmap x/y, direction 360, attack angle.
  * See Changelog.md for a full list.
- Add mypaint-python3-pass-str-to-exec.patch: Fix build with
  python3 by passing a str object as the first arg to exec instead
  of an open file object.
- Drop no longer needed patches:
  * mypaint-scons-to-python3.patch
  * reproducible.patch.
- Adapt to build system overhaul:
  * Switch to using python3.
  * Use python build macros to build and install.
  * New BuildRequires: pkgconfig(gtk+-3.0), pkgconfig(libmypaint)
    >= 1.5.0, pkgconfig(mypaint-brushes-2.0),
    python3-gobject-devel, python3-setuptools, python-rpm-macros,
    pkgconfig(gtk+-3.0).
  * New Requires: python3-gobject-Gdk.
  * Run tests as part of %%check.
  * Use %%autosetup to set up build dir and apply patches.
  * Drop post(un) scriptlets handled by rpm file triggers.
* Mon Oct 28 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire rsvg-convert instead of rsvg-view on TW: the
  rsvg-view program has been dropped, leaving only the rsvg-convert
  binary behind. For this reason, the package name was adjusted
  to properly reflect its content.
* Sun Jun  9 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to sort file list to make build reproducible
  (boo#1041090)
* Thu Sep 20 2018 antoine.belvire@opensuse.org
- Make mypaint work again (boo#1081099): Explicitely set
  python_binary and python_config to python2.7(-config).
- Spec file minor cleanup.
* Wed May  2 2018 badshah400@gmail.com
- Drop devel pkg: no one is using it and libmypaint-devel >= 1.3
  obsoletes it.
* Mon Apr 30 2018 jengelh@inai.de
- Limit fdupes to one partition, /usr.
- Remove unnecessary ldconfig calls; there are no shared libraries
  in the standard search paths.
- Use find -delete instead of the slower xargs.
* Sat Apr 28 2018 badshah400@gmail.com
- Updated standalone library libmypaint already provides its own
  lang files; just strip mypaint-lang of all libmypaint.mo files
  to avoid a file conflict between the libmypaint-lang and
  mypaint-lang.
- Recommend instead of requiring lang package.
- Don't run desktop database and icon cache update scripts as part
  of post(un) for openSUSE >=1500; these are taken care of by
  rpm's file triggers.
- Fix env-based hashbang in the main app binary.
* Sun Dec 10 2017 i@marguerite.su
- rework mypaint-scons-to-python3.patch
  * fix more 'print' parentheses
* Fri Nov 24 2017 badshah400@opensuse.org
- Add mypaint-scons-to-python3.patch Convert SCons* to python3 for
  compatibility with openSUSE > 1320 where scons is python3-based.
* Tue Jun 13 2017 jengelh@inai.de
- Trim filler wording from description and put something more
  concrete in there.
* Sun Jun  4 2017 plinnell@opensuse.org
- Fix URL and download to correct location.
* Thu Mar 17 2016 meissner@suse.com
- revert to 1.1.0.
  1.2.0 needs the pygtk2compat layer that is not included in openSUSE :(
  Go to a newer version once it is fully ported to Gtk3.
* Wed Mar 16 2016 meissner@suse.com
- updated to 1.2.0
  - New intuitive Inking tool for smooth strokes.
  - New Flood Fill tool.
  - Automated backups of your working docs, with recovery on startup.
  - Improved symmetry-setting and frame-setting modes.
  - New workspace UI: two sidebars, with dockable tabbed panels.
  - Smoother scrolling and panning.
  - New brush pack.
  - New brush and color history panel.
  - New layer trimming command in frame options.
  - Added layer groups.
  - New layer modes: several masking modes added.
  - Add display filters: greyscale, simulate dichromacy for trichromats.
  - New color wheel options: Red/Yellow/Blue, Red-Green/Blue-Yellow.
  - Uses dark theme variant by default.
  - Clearer icons, prettier freehand cursors.
  - Device prefs allow glitchy devices to be restricted.
  - Eraser mode no longer changes the size of the brush.
  - New vector layers, editable in an external app (Inkscape recommended).
  - New fallback layer types: non-PNG image, data.
  - More kinds of images now work as backgrounds.
  - Improved Windows support
  - Ported to GTK3.
  - Accelerator map editor has moved to preferences.
  - Many other bugfixes, translations, and code quality improvements.
* Fri Sep 18 2015 malcolmlewis@opensuse.org
- Fix spec file for aarch64 builds.
* Thu Aug 21 2014 malcolmlewis@opensuse.org
- Fix spec file for ppc64le builds.
* Wed Feb  5 2014 malcolmlewis@opensuse.org
- Fix spec file for ppc64 builds.
* Thu Mar 14 2013 gankov@opensuse.org
- Requires updated to use python-numpy >= 1.7 for openSUSE 12.2+
* Sat Jan  5 2013 zawertun@gmail.com
- Updated to 1.1.0:
  + Geometry tools: sequence of lines, curved lines, ellipses;
  + New brush and layer blending modes; different layer merging;
  + New color dialog: palette and gamut mapping;
  + Improved document frame, can be resized on canvas;
  + Symmetric drawing mode;
  + Old color changer ("washed") from 0.6 is available again;
  + Toolbar improvements, e.g. move layer mode, pan/zoom;
  + Revised cursor and on-canvas color picker;
  + Better separation of mypaint's brush library; json brush file
    format;
  + Translations, performance improvements, bugfixes, and more.
* Fri Dec 16 2011 malcolmlewis@opensuse.org
- Add icon_theme_cache macro as icon theme needs to be updated
  (https://gna.org/bugs/?18460).
* Tue Dec 13 2011 malcolmlewis@opensuse.org
- Re add changelog history.
- Fix incorrect icon sizes as per rpmlint report.
- Fix incorrect file permissions, source has them as 0755.
- Set correct library path for build arch.
- Drop additional CFLAGS as now included in setup.py.
- Add icon in /usr/share/pixmaps for desktop file.
* Mon Dec 12 2011 idonmez@suse.com
- spec file cleanup.
* Sun Nov 27 2011 i@marguerite.su
- Updated to version 1.0.0:
  + Toolbar with color, brush selector and brush settings
    dropdown.
  + Tool windows can be docked instead of floating.
  + Locked alpha brush mode.
  + Basic layer compositing modes.
  + New scratchpad area.
  + Lots of other improvements (about 500 commits).
* Tue Jun 28 2011 malcolmlewis@opensuse.org
- Clean up spec file for 11.4 builds.
- Add icon names in icon directories.
- Update spec file Licence field from GPLv2 to GPL-2.0 to conform
  with spdx.org identifier.
* Tue Mar 22 2011 malcolmlewis@opensuse.org
- Update to 0.9.1
  * several fixes for non-ascii file names, directories, layer names
  * workaround for tablets reporting invalid tilt values
  * rotation: fix direction while mirrored, change steps to 22.5 degrees
  * store freedesktop thumbnails also when saving (for preview in other apps)
  * reduce the minimal cursor size
  * brush selector: remember state of the expander at the bottom
  * fix glitch when changing the brush/color with a different input device
  * osx: fix compile error
  * windows: use AppData folder for settings
  * some other minor fixes
- spec file clean up
* Wed Jan 12 2011 malcolmlewis@opensuse.org
- Requires updated to use scons >= 1.2
* Tue Jan 11 2011 malcolmlewis@opensuse.org
- Fix spec file requires
* Mon Jan 10 2011 malcolmlewis@opensuse.org
- Add python-numpy Requires >= 1.5 to avoid seg fault
* Thu Nov 11 2010 malcolmlewis@opensuse.org
- New Version
  + brush collection: updated better and smaller collection
  + brushset import and export
  + improvement for jaggy lines on Windows (might also fix saving problems)
  + fixes for non-ascii brush- and filenames (for Windows mainly)
  + sharper image for some zoom levels
  + stylus tilt support
  + persistence of selected brush and group
  + file preview in open dialog
  + configurable default save format and zoom level
  + optimizations: faster startup, much faster saving
  + lots of small improvements, bug fixes, optimizations
  + updated translations: hu,es,ru,sv,nb,nn_NO,sl,ko,it
  + improved exception dialog
  + added GIMP-style subwindow toggle
  + added GIMP-style cursor-menu
  + usability improvements for brush selector and brush settings dialog
  + added file->export action
* Tue Sep 14 2010 malcolmlewis@opensuse.org
- Further spec clean up
* Wed Jun 30 2010 malcolmlewis@opensuse.org
- Spec clean up
* Wed Mar 31 2010 coyoteuser@gmail.com
- new version
  + fix regression in 0.8.1 causing temporary layers to stick
  + complain about unsupported pygtk version
* Mon Mar  1 2010 coyoteuser@gmail.com
- new version 0.8.1
  + fixed memory leak: layer data was never freed, eg. when opening a new image
  + fixed loading of layer names
  + respect layer visibility when saving to PNG
  + fixed a freeze in the exception dialog
  + added empty "favorites" brushgroup
  + Korean translation
  + some minor gui fixes
* Mon Feb  8 2010 coyoteuser@gmail.com
- version bump
- rpmlintrc added
* Mon Nov 23 2009 coyoteuser@gmail.com
- readded to OBS
- fixed spec for 1120 builds
* Thu Aug  6 2009 coyoteuser@gmail.com
- added Requires for python-numpy
- added patch to remove CXX flags
- added build requires gcc-c++ and update-desktop-files
- initial build
